==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fIf__5ficmpgt.h <==
// class soot.coffi.Instruction_If_icmpgt

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 424c291b0a7c7961 soot_coffi_Instruction__5fIf__5ficmpgt
// @dep_class f1ed2760eb94209e soot_coffi_Instruction__5fbranch
// @dep_class 6bcdce6545109d8e soot_coffi_Instruction__5fintbranch

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintbranch

#include "soot/coffi/Instruction__5fintbranch.h"

#ifndef _JC_soot_coffi_Instruction__5fIf__5ficmpgt_H_
#define _JC_soot_coffi_Instruction__5fIf__5ficmpgt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$sub_refs	_jc_soot_coffi_Instruction__5fIf__5ficmpgt$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$sub_nonrefs	_jc_soot_coffi_Instruction__5fIf__5ficmpgt$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$refs	_jc_soot_coffi_Instruction__5fIf__5ficmpgt$refs;
typedef struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$nonrefs	_jc_soot_coffi_Instruction__5fIf__5ficmpgt$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$object	_jc_soot_coffi_Instruction__5fIf__5ficmpgt$object;

typedef const struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$vmethods	_jc_soot_coffi_Instruction__5fIf__5ficmpgt$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$vtable	_jc_soot_coffi_Instruction__5fIf__5ficmpgt$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$vtype	_jc_soot_coffi_Instruction__5fIf__5ficmpgt$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fIf__5ficmpgt$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbranch$vmethods	soot_coffi_Instruction__5fbranch;
	_jc_soot_coffi_Instruction__5fintbranch$vmethods	soot_coffi_Instruction__5fintbranch;
	_jc_soot_coffi_Instruction__5fIf__5ficmpgt$vmethods	soot_coffi_Instruction__5fIf__5ficmpgt;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fIf__5ficmpgt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$refs {
    _jc_soot_coffi_Instruction__5fIf__5ficmpgt$sub_refs	soot_coffi_Instruction__5fIf__5ficmpgt;
    _jc_soot_coffi_Instruction__5fintbranch$sub_refs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fbranch$sub_refs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbranch$sub_nonrefs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction__5fintbranch$sub_nonrefs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fIf__5ficmpgt$sub_nonrefs	soot_coffi_Instruction__5fIf__5ficmpgt;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$object {
	_jc_soot_coffi_Instruction__5fIf__5ficmpgt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fIf__5ficmpgt$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fIf__5ficmpgt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fIf__5ficmpgt$vtype _jc_soot_coffi_Instruction__5fIf__5ficmpgt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fIf__5ficmpgt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fIf__5ficmpgt$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fIf__5ficmpgt_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fIf__5ficmpgt.h <==
// class soot.coffi.Instruction_If_icmpgt

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 424c291b0a7c7961 soot_coffi_Instruction__5fIf__5ficmpgt
// @dep_class f1ed2760eb94209e soot_coffi_Instruction__5fbranch
// @dep_class 6bcdce6545109d8e soot_coffi_Instruction__5fintbranch

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintbranch

#include "soot/coffi/Instruction__5fintbranch.h"

#ifndef _JC_soot_coffi_Instruction__5fIf__5ficmpgt_H_
#define _JC_soot_coffi_Instruction__5fIf__5ficmpgt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$sub_refs	_jc_soot_coffi_Instruction__5fIf__5ficmpgt$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$sub_nonrefs	_jc_soot_coffi_Instruction__5fIf__5ficmpgt$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$refs	_jc_soot_coffi_Instruction__5fIf__5ficmpgt$refs;
typedef struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$nonrefs	_jc_soot_coffi_Instruction__5fIf__5ficmpgt$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$object	_jc_soot_coffi_Instruction__5fIf__5ficmpgt$object;

typedef const struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$vmethods	_jc_soot_coffi_Instruction__5fIf__5ficmpgt$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$vtable	_jc_soot_coffi_Instruction__5fIf__5ficmpgt$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$vtype	_jc_soot_coffi_Instruction__5fIf__5ficmpgt$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fIf__5ficmpgt$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbranch$vmethods	soot_coffi_Instruction__5fbranch;
	_jc_soot_coffi_Instruction__5fintbranch$vmethods	soot_coffi_Instruction__5fintbranch;
	_jc_soot_coffi_Instruction__5fIf__5ficmpgt$vmethods	soot_coffi_Instruction__5fIf__5ficmpgt;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fIf__5ficmpgt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$refs {
    _jc_soot_coffi_Instruction__5fIf__5ficmpgt$sub_refs	soot_coffi_Instruction__5fIf__5ficmpgt;
    _jc_soot_coffi_Instruction__5fintbranch$sub_refs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fbranch$sub_refs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbranch$sub_nonrefs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction__5fintbranch$sub_nonrefs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fIf__5ficmpgt$sub_nonrefs	soot_coffi_Instruction__5fIf__5ficmpgt;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fIf__5ficmpgt$object {
	_jc_soot_coffi_Instruction__5fIf__5ficmpgt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fIf__5ficmpgt$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fIf__5ficmpgt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fIf__5ficmpgt$vtype _jc_soot_coffi_Instruction__5fIf__5ficmpgt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fIf__5ficmpgt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fIf__5ficmpgt$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fIf__5ficmpgt_H_ */
